@@ -17,6 +17,8 @@ def _get_kwargs(
     runnable_type: Union[Unset, None, GetInputHistoryRunnableType] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    include_preview: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -33,6 +35,10 @@ def _get_kwargs(
 
     params["per_page"] = per_page
 
+    params["args"] = args
+
+    params["include_preview"] = include_preview
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -81,6 +87,8 @@ def sync_detailed(
     runnable_type: Union[Unset, None, GetInputHistoryRunnableType] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    include_preview: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["GetInputHistoryResponse200Item"]]:
     """List Inputs used in previously completed jobs
 
@@ -90,6 +98,8 @@ def sync_detailed(
         runnable_type (Union[Unset, None, GetInputHistoryRunnableType]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        args (Union[Unset, None, str]):
+        include_preview (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -105,6 +115,8 @@ def sync_detailed(
         runnable_type=runnable_type,
         page=page,
         per_page=per_page,
+        args=args,
+        include_preview=include_preview,
     )
 
     response = client.get_httpx_client().request(
@@ -122,6 +134,8 @@ def sync(
     runnable_type: Union[Unset, None, GetInputHistoryRunnableType] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    include_preview: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["GetInputHistoryResponse200Item"]]:
     """List Inputs used in previously completed jobs
 
@@ -131,6 +145,8 @@ def sync(
         runnable_type (Union[Unset, None, GetInputHistoryRunnableType]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        args (Union[Unset, None, str]):
+        include_preview (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -147,6 +163,8 @@ def sync(
         runnable_type=runnable_type,
         page=page,
         per_page=per_page,
+        args=args,
+        include_preview=include_preview,
     ).parsed
 
 
@@ -158,6 +176,8 @@ async def asyncio_detailed(
     runnable_type: Union[Unset, None, GetInputHistoryRunnableType] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    include_preview: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["GetInputHistoryResponse200Item"]]:
     """List Inputs used in previously completed jobs
 
@@ -167,6 +187,8 @@ async def asyncio_detailed(
         runnable_type (Union[Unset, None, GetInputHistoryRunnableType]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        args (Union[Unset, None, str]):
+        include_preview (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -182,6 +204,8 @@ async def asyncio_detailed(
         runnable_type=runnable_type,
         page=page,
         per_page=per_page,
+        args=args,
+        include_preview=include_preview,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -197,6 +221,8 @@ async def asyncio(
     runnable_type: Union[Unset, None, GetInputHistoryRunnableType] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    args: Union[Unset, None, str] = UNSET,
+    include_preview: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["GetInputHistoryResponse200Item"]]:
     """List Inputs used in previously completed jobs
 
@@ -206,6 +232,8 @@ async def asyncio(
         runnable_type (Union[Unset, None, GetInputHistoryRunnableType]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
+        args (Union[Unset, None, str]):
+        include_preview (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -223,5 +251,7 @@ async def asyncio(
             runnable_type=runnable_type,
             page=page,
             per_page=per_page,
+            args=args,
+            include_preview=include_preview,
         )
     ).parsed
