@@ -16,6 +16,7 @@ def _get_kwargs(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
     schedule_path: Union[Unset, None, str] = UNSET,
@@ -29,6 +30,7 @@ def _get_kwargs(
     running: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -44,6 +46,8 @@ def _get_kwargs(
 
     params["parent_job"] = parent_job
 
+    params["worker"] = worker
+
     params["script_path_exact"] = script_path_exact
 
     params["script_path_start"] = script_path_start
@@ -78,6 +82,8 @@ def _get_kwargs(
 
     params["result"] = result
 
+    params["allow_wildcards"] = allow_wildcards
+
     params["tag"] = tag
 
     params["page"] = page
@@ -135,6 +141,7 @@ def sync_detailed(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
     schedule_path: Union[Unset, None, str] = UNSET,
@@ -148,6 +155,7 @@ def sync_detailed(
     running: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -161,6 +169,7 @@ def sync_detailed(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
         schedule_path (Union[Unset, None, str]):
@@ -174,6 +183,7 @@ def sync_detailed(
         running (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -193,6 +203,7 @@ def sync_detailed(
         order_desc=order_desc,
         created_by=created_by,
         parent_job=parent_job,
+        worker=worker,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
         schedule_path=schedule_path,
@@ -206,6 +217,7 @@ def sync_detailed(
         running=running,
         args=args,
         result=result,
+        allow_wildcards=allow_wildcards,
         tag=tag,
         page=page,
         per_page=per_page,
@@ -227,6 +239,7 @@ def sync(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
     schedule_path: Union[Unset, None, str] = UNSET,
@@ -240,6 +253,7 @@ def sync(
     running: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -253,6 +267,7 @@ def sync(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
         schedule_path (Union[Unset, None, str]):
@@ -266,6 +281,7 @@ def sync(
         running (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -286,6 +302,7 @@ def sync(
         order_desc=order_desc,
         created_by=created_by,
         parent_job=parent_job,
+        worker=worker,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
         schedule_path=schedule_path,
@@ -299,6 +316,7 @@ def sync(
         running=running,
         args=args,
         result=result,
+        allow_wildcards=allow_wildcards,
         tag=tag,
         page=page,
         per_page=per_page,
@@ -314,6 +332,7 @@ async def asyncio_detailed(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
     schedule_path: Union[Unset, None, str] = UNSET,
@@ -327,6 +346,7 @@ async def asyncio_detailed(
     running: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -340,6 +360,7 @@ async def asyncio_detailed(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
         schedule_path (Union[Unset, None, str]):
@@ -353,6 +374,7 @@ async def asyncio_detailed(
         running (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -372,6 +394,7 @@ async def asyncio_detailed(
         order_desc=order_desc,
         created_by=created_by,
         parent_job=parent_job,
+        worker=worker,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
         schedule_path=schedule_path,
@@ -385,6 +408,7 @@ async def asyncio_detailed(
         running=running,
         args=args,
         result=result,
+        allow_wildcards=allow_wildcards,
         tag=tag,
         page=page,
         per_page=per_page,
@@ -404,6 +428,7 @@ async def asyncio(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
     schedule_path: Union[Unset, None, str] = UNSET,
@@ -417,6 +442,7 @@ async def asyncio(
     running: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -430,6 +456,7 @@ async def asyncio(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
         schedule_path (Union[Unset, None, str]):
@@ -443,6 +470,7 @@ async def asyncio(
         running (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -464,6 +492,7 @@ async def asyncio(
             order_desc=order_desc,
             created_by=created_by,
             parent_job=parent_job,
+            worker=worker,
             script_path_exact=script_path_exact,
             script_path_start=script_path_start,
             schedule_path=schedule_path,
@@ -477,6 +506,7 @@ async def asyncio(
             running=running,
             args=args,
             result=result,
+            allow_wildcards=allow_wildcards,
             tag=tag,
             page=page,
             per_page=per_page,
