@@ -13,6 +13,9 @@ if TYPE_CHECKING:
     from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_1 import (
         CompletedJobFlowStatusFailureModuleAgentActionsItemType1,
     )
+    from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_2 import (
+        CompletedJobFlowStatusFailureModuleAgentActionsItemType2,
+    )
     from ..models.completed_job_flow_status_failure_module_approvers_item import (
         CompletedJobFlowStatusFailureModuleApproversItem,
     )
@@ -48,7 +51,8 @@ class CompletedJobFlowStatusFailureModule:
         failed_retries (Union[Unset, List[str]]):
         skipped (Union[Unset, bool]):
         agent_actions (Union[Unset, List[Union['CompletedJobFlowStatusFailureModuleAgentActionsItemType0',
-            'CompletedJobFlowStatusFailureModuleAgentActionsItemType1']]]):
+            'CompletedJobFlowStatusFailureModuleAgentActionsItemType1',
+            'CompletedJobFlowStatusFailureModuleAgentActionsItemType2']]]):
         agent_actions_success (Union[Unset, List[bool]]):
         parent_module (Union[Unset, str]):
     """
@@ -73,6 +77,7 @@ class CompletedJobFlowStatusFailureModule:
             Union[
                 "CompletedJobFlowStatusFailureModuleAgentActionsItemType0",
                 "CompletedJobFlowStatusFailureModuleAgentActionsItemType1",
+                "CompletedJobFlowStatusFailureModuleAgentActionsItemType2",
             ]
         ],
     ] = UNSET
@@ -84,6 +89,9 @@ class CompletedJobFlowStatusFailureModule:
         from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_0 import (
             CompletedJobFlowStatusFailureModuleAgentActionsItemType0,
         )
+        from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_1 import (
+            CompletedJobFlowStatusFailureModuleAgentActionsItemType1,
+        )
 
         type = self.type.value
 
@@ -137,6 +145,9 @@ class CompletedJobFlowStatusFailureModule:
                 if isinstance(agent_actions_item_data, CompletedJobFlowStatusFailureModuleAgentActionsItemType0):
                     agent_actions_item = agent_actions_item_data.to_dict()
 
+                elif isinstance(agent_actions_item_data, CompletedJobFlowStatusFailureModuleAgentActionsItemType1):
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
                 else:
                     agent_actions_item = agent_actions_item_data.to_dict()
 
@@ -198,6 +209,9 @@ class CompletedJobFlowStatusFailureModule:
         from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_1 import (
             CompletedJobFlowStatusFailureModuleAgentActionsItemType1,
         )
+        from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_2 import (
+            CompletedJobFlowStatusFailureModuleAgentActionsItemType2,
+        )
         from ..models.completed_job_flow_status_failure_module_approvers_item import (
             CompletedJobFlowStatusFailureModuleApproversItem,
         )
@@ -277,6 +291,7 @@ class CompletedJobFlowStatusFailureModule:
             ) -> Union[
                 "CompletedJobFlowStatusFailureModuleAgentActionsItemType0",
                 "CompletedJobFlowStatusFailureModuleAgentActionsItemType1",
+                "CompletedJobFlowStatusFailureModuleAgentActionsItemType2",
             ]:
                 try:
                     if not isinstance(data, dict):
@@ -286,11 +301,19 @@ class CompletedJobFlowStatusFailureModule:
                     return agent_actions_item_type_0
                 except:  # noqa: E722
                     pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    agent_actions_item_type_1 = CompletedJobFlowStatusFailureModuleAgentActionsItemType1.from_dict(data)
+
+                    return agent_actions_item_type_1
+                except:  # noqa: E722
+                    pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                agent_actions_item_type_1 = CompletedJobFlowStatusFailureModuleAgentActionsItemType1.from_dict(data)
+                agent_actions_item_type_2 = CompletedJobFlowStatusFailureModuleAgentActionsItemType2.from_dict(data)
 
-                return agent_actions_item_type_1
+                return agent_actions_item_type_2
 
             agent_actions_item = _parse_agent_actions_item(agent_actions_item_data)
 
