@@ -15,17 +15,20 @@ class CreateWorkspaceJsonBody:
         id (str):
         name (str):
         username (Union[Unset, str]):
+        color (Union[Unset, str]):
     """
 
     id: str
     name: str
     username: Union[Unset, str] = UNSET
+    color: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
         name = self.name
         username = self.username
+        color = self.color
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -37,6 +40,8 @@ class CreateWorkspaceJsonBody:
         )
         if username is not UNSET:
             field_dict["username"] = username
+        if color is not UNSET:
+            field_dict["color"] = color
 
         return field_dict
 
@@ -49,10 +54,13 @@ class CreateWorkspaceJsonBody:
 
         username = d.pop("username", UNSET)
 
+        color = d.pop("color", UNSET)
+
         create_workspace_json_body = cls(
             id=id,
             name=name,
             username=username,
+            color=color,
         )
 
         create_workspace_json_body.additional_properties = d
