@@ -1,13 +1,14 @@
 from typing import Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="EditResourceType")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class EditResourceType:
     """
     Attributes:
@@ -17,7 +18,7 @@ class EditResourceType:
 
     schema: Union[Unset, Any] = UNSET
     description: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         schema = self.schema
