@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type2Type(str, Enum):
-    FORLOOPFLOW = "forloopflow"
+    FLOW = "flow"
 
     def __str__(self) -> str:
         return str(self.value)
