@@ -40,6 +40,7 @@ class GetHttpTriggerResponse200:
         edited_by (str):
         edited_at (datetime.datetime):
         is_flow (bool):
+        enabled (bool):
         static_asset_config (Union[Unset, GetHttpTriggerResponse200StaticAssetConfig]):
         authentication_resource_path (Union[Unset, str]):
         summary (Union[Unset, str]):
@@ -66,6 +67,7 @@ class GetHttpTriggerResponse200:
     edited_by: str
     edited_at: datetime.datetime
     is_flow: bool
+    enabled: bool
     static_asset_config: Union[Unset, "GetHttpTriggerResponse200StaticAssetConfig"] = UNSET
     authentication_resource_path: Union[Unset, str] = UNSET
     summary: Union[Unset, str] = UNSET
@@ -97,6 +99,7 @@ class GetHttpTriggerResponse200:
         edited_at = self.edited_at.isoformat()
 
         is_flow = self.is_flow
+        enabled = self.enabled
         static_asset_config: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.static_asset_config, Unset):
             static_asset_config = self.static_asset_config.to_dict()
@@ -133,6 +136,7 @@ class GetHttpTriggerResponse200:
                 "edited_by": edited_by,
                 "edited_at": edited_at,
                 "is_flow": is_flow,
+                "enabled": enabled,
             }
         )
         if static_asset_config is not UNSET:
@@ -194,6 +198,8 @@ class GetHttpTriggerResponse200:
 
         is_flow = d.pop("is_flow")
 
+        enabled = d.pop("enabled")
+
         _static_asset_config = d.pop("static_asset_config", UNSET)
         static_asset_config: Union[Unset, GetHttpTriggerResponse200StaticAssetConfig]
         if isinstance(_static_asset_config, Unset):
@@ -240,6 +246,7 @@ class GetHttpTriggerResponse200:
             edited_by=edited_by,
             edited_at=edited_at,
             is_flow=is_flow,
+            enabled=enabled,
             static_asset_config=static_asset_config,
             authentication_resource_path=authentication_resource_path,
             summary=summary,
