@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.list_queue_response_200_item_raw_flow_failure_module_retry_exponential import (
         ListQueueResponse200ItemRawFlowFailureModuleRetryExponential,
     )
+    from ..models.list_queue_response_200_item_raw_flow_failure_module_retry_retry_if import (
+        ListQueueResponse200ItemRawFlowFailureModuleRetryRetryIf,
+    )
 
 
 T = TypeVar("T", bound="ListQueueResponse200ItemRawFlowFailureModuleRetry")
@@ -23,10 +26,12 @@ class ListQueueResponse200ItemRawFlowFailureModuleRetry:
     Attributes:
         constant (Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleRetryConstant]):
         exponential (Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleRetryExponential]):
+        retry_if (Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleRetryRetryIf]):
     """
 
     constant: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModuleRetryConstant"] = UNSET
     exponential: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModuleRetryExponential"] = UNSET
+    retry_if: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModuleRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -38,6 +43,10 @@ class ListQueueResponse200ItemRawFlowFailureModuleRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -45,6 +54,8 @@ class ListQueueResponse200ItemRawFlowFailureModuleRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -56,6 +67,9 @@ class ListQueueResponse200ItemRawFlowFailureModuleRetry:
         from ..models.list_queue_response_200_item_raw_flow_failure_module_retry_exponential import (
             ListQueueResponse200ItemRawFlowFailureModuleRetryExponential,
         )
+        from ..models.list_queue_response_200_item_raw_flow_failure_module_retry_retry_if import (
+            ListQueueResponse200ItemRawFlowFailureModuleRetryRetryIf,
+        )
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -72,9 +86,17 @@ class ListQueueResponse200ItemRawFlowFailureModuleRetry:
         else:
             exponential = ListQueueResponse200ItemRawFlowFailureModuleRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = ListQueueResponse200ItemRawFlowFailureModuleRetryRetryIf.from_dict(_retry_if)
+
         list_queue_response_200_item_raw_flow_failure_module_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         list_queue_response_200_item_raw_flow_failure_module_retry.additional_properties = d
