@@ -19,6 +19,7 @@ class ListUsersAsSuperAdminResponse200Item:
         login_type (ListUsersAsSuperAdminResponse200ItemLoginType):
         super_admin (bool):
         verified (bool):
+        first_time_user (bool):
         devops (Union[Unset, bool]):
         name (Union[Unset, str]):
         company (Union[Unset, str]):
@@ -30,6 +31,7 @@ class ListUsersAsSuperAdminResponse200Item:
     login_type: ListUsersAsSuperAdminResponse200ItemLoginType
     super_admin: bool
     verified: bool
+    first_time_user: bool
     devops: Union[Unset, bool] = UNSET
     name: Union[Unset, str] = UNSET
     company: Union[Unset, str] = UNSET
@@ -43,6 +45,7 @@ class ListUsersAsSuperAdminResponse200Item:
 
         super_admin = self.super_admin
         verified = self.verified
+        first_time_user = self.first_time_user
         devops = self.devops
         name = self.name
         company = self.company
@@ -57,6 +60,7 @@ class ListUsersAsSuperAdminResponse200Item:
                 "login_type": login_type,
                 "super_admin": super_admin,
                 "verified": verified,
+                "first_time_user": first_time_user,
             }
         )
         if devops is not UNSET:
@@ -83,6 +87,8 @@ class ListUsersAsSuperAdminResponse200Item:
 
         verified = d.pop("verified")
 
+        first_time_user = d.pop("first_time_user")
+
         devops = d.pop("devops", UNSET)
 
         name = d.pop("name", UNSET)
@@ -98,6 +104,7 @@ class ListUsersAsSuperAdminResponse200Item:
             login_type=login_type,
             super_admin=super_admin,
             verified=verified,
+            first_time_user=first_time_user,
             devops=devops,
             name=name,
             company=company,
